@@ -5,13 +5,15 @@ use warnings;
 
 use Mojo::Client;
 use Mojo::JSON;
-use IO::Socket::SSL;
+use IO::Socket::SSL 1.37;
 
 use Google::Voice::Feed;
 use Google::Voice::Call;
 
 use base 'Mojo::Base';
 
+our $VERSION = 0.02;
+
 __PACKAGE__->attr([qw/ client rnr_se /]);
 
 sub new {
@@ -131,52 +133,52 @@ sub call {
 
 =head1 NAME
 
-Google::Voice
+Google::Voice - Easy interface for google voice
 
 =head1 DESCRIPTION
 
-google.com/voice services
+Easy interface for google voice
 
 =head1 USAGE
 
-	use Google::Voice;
+    use Google::Voice;
 
-	my $g = Google::Voice->new->login('username', 'password');
+    my $g = Google::Voice->new->login('username', 'password');
 
-	# Send sms
-	$g->send_sms(5555555555 => 'Hello friend!');
+    # Send sms
+    $g->send_sms(5555555555 => 'Hello friend!');
 
-	# Error code from google on fail
-	print $@ if ! $g->send_sms('invalid phone' => 'text message');
-	
-	# connect call & cancel it
-	my $call = $g->call( '+15555555555' => '+14444444444' );
-	$call->cancel;
+    # Error code from google on fail
+    print $@ if !$g->send_sms('invalid phone' => 'text message');
 
-	
-	# Print all sms conversations
-	foreach my $sms ( $g->sms ) {
-	    print $sms->name;
-	    print $_->time , ':', $_->text, "\n" foreach $sms->messages;
+    # connect call & cancel it
+    my $call = $g->call('+15555555555' => '+14444444444');
+    $call->cancel;
 
-		# Delete conversation
-		$sms->delete;
-	}
 
-	# loop through voicemail messages
-	foreach my $vm ( $g->voicemail ) {
+    # Print all sms conversations
+    foreach my $sms ($g->sms) {
+        print $sms->name;
+        print $_->time, ':', $_->text, "\n" foreach $sms->messages;
 
-		# Name, number, and transcribed text
-		print $vm->name . "\n";
-		print $vm->meta->{phoneNumber} . "\n";
-		print $vm->text . "\n";
-		
-		# Download mp3
-		$vm->download->move_to( $vm->id . '.mp3' );
+        # Delete conversation
+        $sms->delete;
+    }
 
-		# Delete
-		$vm->delete;
-	}
+    # loop through voicemail messages
+    foreach my $vm ($g->voicemail) {
+
+        # Name, number, and transcribed text
+        print $vm->name . "\n";
+        print $vm->meta->{phoneNumber} . "\n";
+        print $vm->text . "\n";
+
+        # Download mp3
+        $vm->download->move_to($vm->id . '.mp3');
+
+        # Delete
+        $vm->delete;
+    }
 
 =head1 METHODS
 
@@ -242,7 +244,7 @@ L<http://github.com/tempire/perl-google-voice>
 
 =head1 VERSION
 
-0.0101
+0.02
 
 =head1 AUTHOR
 
